@@ -34,6 +34,7 @@
 #include <intel_bufmgr.h>
 
 #include "i965_gpe_utils.h"
+#include "i965_encoder.h"
 
 struct encode_state;
 
@@ -49,7 +50,6 @@ struct encode_state;
 /* the space required for slice tail. */
 #define SLICE_TAIL			16
 
-#define __SOFTWARE__    0
 
 #define MFC_BATCHBUFFER_AVC_INTRA       0
 #define MFC_BATCHBUFFER_AVC_INTER       1
@@ -61,6 +61,85 @@ struct encode_state;
 
 #define CMD_LEN_IN_OWORD        4
 
+#define BRC_CLIP(x, min, max)                                   \
+    {                                                           \
+        x = ((x > (max)) ? (max) : ((x < (min)) ? (min) : x));  \
+    }
+
+#define BRC_P_B_QP_DIFF 4
+#define BRC_I_P_QP_DIFF 2
+#define BRC_I_B_QP_DIFF (BRC_I_P_QP_DIFF + BRC_P_B_QP_DIFF)
+
+#define BRC_PWEIGHT 0.6  /* weight if P slice with comparison to I slice */
+#define BRC_BWEIGHT 0.25 /* weight if B slice with comparison to I slice */
+
+#define BRC_QP_MAX_CHANGE 5 /* maximum qp modification */
+#define BRC_CY 0.1 /* weight for */
+#define BRC_CX_UNDERFLOW 5.
+#define BRC_CX_OVERFLOW -4.
+
+#define BRC_PI_0_5 1.5707963267948966192313216916398
+
+typedef enum {
+   VME_V_PRED = 0,
+   VME_H_PRED = 1,
+   VME_DC_PRED = 2,
+   VME_PL_PRED = 3,
+
+   VME_MB_INTRA_MODE_COUNT
+} VME_MB_INTRA_PRED_MODE;
+
+typedef enum {
+   PAK_DC_PRED = 0,
+   PAK_V_PRED = 1,
+   PAK_H_PRED = 2,
+   PAK_TM_PRED = 3,
+
+   PAK_MB_INTRA_MODE_COUNT
+} VP8_PAK_MB_INTRA_PRED_MODE;
+
+typedef enum
+{
+    VME_B_V_PRED = 0,
+    VME_B_H_PRED = 1,
+    VME_B_DC_PRED = 2,
+    VME_B_DL_PRED = 3,
+    VME_B_DR_PRED = 4,
+    VME_B_VR_PRED = 5,
+    VME_B_HD_PRED = 6,
+    VME_B_VL_PRED = 7,
+    VME_B_HU_PRED = 8,
+
+    VME_B_INTRA_MODE_COUNT
+} VME_BLOCK_INTRA_PRED_MODE;
+
+typedef enum
+{
+    PAK_B_DC_PRED = 0,
+    PAK_B_TM_PRED = 1,
+    PAK_B_VE_PRED = 2,
+    PAK_B_HE_PRED = 3,
+    PAK_B_LD_PRED = 4,
+    PAK_B_RD_PRED = 5,
+    PAK_B_VR_PRED = 6,
+    PAK_B_VL_PRED = 7,
+    PAK_B_HD_PRED = 8,
+    PAK_B_HU_PRED = 9,
+
+    PAK_B_INTRA_MODE_COUNT
+} VP8_PAK_BLOCK_INTRA_PRED_MODE;
+
+typedef struct
+{
+  int vme_intra_mb_mode;
+  int vp8_pak_intra_mb_mode;
+} vp8_intra_mb_mode_map_t;
+
+typedef struct
+{
+  int vme_intra_block_mode;
+  int vp8_pak_intra_block_mode;
+} vp8_intra_block_mode_map_t;
 
 typedef enum _gen6_brc_status
 {
@@ -189,6 +268,37 @@ struct gen6_mfc_context
         int i_cpb_removal_delay_length;
         int i_dpb_output_delay_length;
     }vui_hrd;
+ 
+    struct {
+        unsigned char *vp8_frame_header;
+        unsigned int frame_header_bit_count;
+        unsigned int frame_header_qindex_update_pos;
+        unsigned int frame_header_lf_update_pos;
+        unsigned int frame_header_token_update_pos;
+        unsigned int frame_header_bin_mv_upate_pos;
+
+        unsigned int intermediate_partition_offset[8];
+        unsigned int intermediate_buffer_max_size;
+        unsigned int final_frame_byte_offset;
+
+        unsigned char mb_segment_tree_probs[3];
+        unsigned char y_mode_probs[4];
+        unsigned char uv_mode_probs[3];
+        unsigned char mv_probs[2][19];
+
+        unsigned char prob_skip_false;
+        unsigned char prob_intra;
+        unsigned char prob_last;
+        unsigned char prob_gf;
+        
+        dri_bo *frame_header_bo;
+        dri_bo *intermediate_bo;
+        dri_bo *final_frame_bo;
+        dri_bo *stream_out_bo;
+        dri_bo *coeff_probs_stream_in_bo;
+        dri_bo *token_statistics_bo;
+        dri_bo *mpc_row_store_bo;
+    }vp8_state;
 
     //"buffered_QMatrix" will be used to buffer the QMatrix if the app sends one.
     // Or else, we will load a default QMatrix from the driver for JPEG encode.
@@ -209,8 +319,10 @@ struct gen6_mfc_context
                           struct encode_state *encode_state,
                           struct intel_encoder_context *encoder_context);
     void (*avc_qm_state)(VADriverContextP ctx,
+                         struct encode_state *encode_state,
                          struct intel_encoder_context *encoder_context);
     void (*avc_fqm_state)(VADriverContextP ctx,
+                          struct encode_state *encode_state,
                           struct intel_encoder_context *encoder_context);
     void (*insert_object)(VADriverContextP ctx,
                           struct intel_encoder_context *encoder_context,
